<?php
/*
Plugin Name: Facebook Status - Email Updater
Plugin URI: http://www.cjellison.com/fbseu/
Description: Sends an email to update a Facebook status via email for profiles or pages. Can also send an email to any email address.
Version: 1.2
Author: Chris Ellison
Author URI: http://www.cjellison.com
*/

//--------------------------------------------------------------

/*  Copyright 2012  Chris Ellison  (email : cje@cjellison.com)

    This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2, as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

//--------------------------------------------------------------

// activation/deactivation functions inspired by http://corpocrat.com/2009/12/27/tutorial-how-to-write-a-wordpress-plugin/
// uninstall function inspired by http://wordpress.stackexchange.com/questions/25910/uninstall-activate-deactivate-a-plugin-typical-features-how-to/25979#25979

/* Runs when plugin is activated */
register_activation_hook(__FILE__,'fbseu_install'); 

/* Runs on plugin deactivation*/
register_deactivation_hook( __FILE__, 'fbseu_deactivate' );

function fbseu_install() {
/* Creates new database field */
add_option('fbseu_secret_email');
add_option('fbseu_new_to_publish', "1");
add_option('fbseu_draft_to_publish', "1");
add_option('fbseu_pending_to_publish', "1");
add_option('fbseu_private_to_publish', "1");
add_option('fbseu_future_to_publish', "1");
if(get_option('fb_secret_email')) {
	update_option('fbseu_secret_email', get_option('fb_secret_email'));
	delete_option('fb_secret_email');
}
add_option('fbseu_link_type', 'shortlink');
add_option('fbseu_subject_template', "Read [title] at [url]");
}

function fbseu_deactivate() {
/* Really does nothing for now. */
}


//--------------------------------------------------------------

function fbseu_options_page()
{

?>
<div class="wrap">
	<h2>FaceBook Status - Email Updater</h2>
	<p><ul>
		<li>For your personal (mobile) email, you can find your mobile email here: <a href="https://m.facebook.com/upload.php" target="_blank">Facebook Mobile Upload</a>.</li>
		<li>For a page, you need to visit that page, click "Edit Page" in the upper-right corner, go to the "Mobile" tab in the sidebar, and look for it under the "With Mobile Email" section.</li>
 	</ul></p>
	<?php
	if($_POST['fbseu_secret_email']) {
		// set the post formatting options
		update_option('fbseu_secret_email', $_POST['fbseu_secret_email']);
		update_option('fbseu_new_to_publish', $_POST['fbseu_new_to_publish']);
		update_option('fbseu_draft_to_publish', $_POST['fbseu_draft_to_publish']);
		update_option('fbseu_pending_to_publish', $_POST['fbseu_pending_to_publish']);
		update_option('fbseu_private_to_publish', $_POST['fbseu_private_to_publish']);
		update_option('fbseu_future_to_publish', $_POST['fbseu_future_to_publish']);
		update_option('fbseu_link_type', $_POST['fbseu_link_type']);
		update_option('fbseu_subject_template', $_POST['fbseu_subject_template']);
		echo '<div class="updated"><p>Settings have been updated.</p></div>';
	}
	?>
<br>
	<form method="post">
	<fieldset class="options">
		<label for="fbseu_secret_email">Please indicate the secret email:</label>
		<input type="text" name="fbseu_secret_email" style="width: 200px;margin-bottom:10px;" value="<?php print get_option('fbseu_secret_email'); ?>" />
		<br>
		<h4>Send an email when:</h4>
			<input type="checkbox" name="fbseu_new_to_publish" style="margin-bottom:10px;" value="1" <?php if(get_option('fbseu_new_to_publish') == "1") {echo "checked=\"checked\"";} ?> /> post status changes from "New" to "Published"<br>
			<input type="checkbox" name="fbseu_draft_to_publish" style="margin-bottom:10px;" value="1" <?php if(get_option('fbseu_draft_to_publish') == "1") {echo "checked=\"checked\"";} ?> /> post status changes from "Draft" to "Published"<br>
			<input type="checkbox" name="fbseu_pending_to_publish" style="margin-bottom:10px;" value="1" <?php if(get_option('fbseu_pending_to_publish') == "1") {echo "checked=\"checked\"";} ?> /> post status changes from "Pending" to "Published"<br>
			<input type="checkbox" name="fbseu_private_to_publish" style="margin-bottom:10px;" value="1" <?php if(get_option('fbseu_private_to_publish') == "1") {echo "checked=\"checked\"";} ?> /> post status changes from "Private" to "Published"<br>
			<input type="checkbox" name="fbseu_future_to_publish" style="margin-bottom:10px;" value="1" <?php if(get_option('fbseu_future_to_publish') == "1") {echo "checked=\"checked\"";} ?> /> post status changes from "Future" to "Published"<br>
		<br>
		<h4>URL settings:</h4>
			<input type="radio" name="fbseu_link_type" style="margin-bottom:10px;" value="permalink" <?php if(get_option('fbseu_link_type') !== 'shortlink') {echo "checked=\"checked\"";} ?> /> Use permalinks (full URLs)<br>
			<input type="radio" name="fbseu_link_type" style="margin-bottom:10px;" value="shortlink" <?php if(get_option('fbseu_link_type') == 'shortlink') {echo "checked=\"checked\"";} ?> />  Use shortlinks (shortened URLs, will use wp.me if possible)
		<br>
		<h4>Subject template</h4>
			<label for="fbseu_subject_sep">The template you want to use for the subject of the email:</label>
			<input type="text" name="fbseu_subject_template" style="width: 200px;" value="<?php print htmlentities2(stripslashes_deep(get_option('fbseu_subject_template'))); ?>" /><br><div style="margin-bottom:10px;margin-left:7%;">Template shortcodes:<br>-  [title] for the post title<br>-  [url] for the URL based on the type of link chosen above</div>
		<br>
		<input type="submit" value="Save Changes" class="button-primary" />

	</fieldset>
	</form>
</div>
<?php
}

//--------------------------------------------------------------

function fbseu_add_menu()
{
	add_options_page('Facebook Status - Email Updater', 'FB Status Updater', 8, __FILE__, 'fbseu_options_page');
}
add_action('admin_menu', 'fbseu_add_menu');


//--------------------------------------------------------------

function fbseu_send_email($post)  {
	if(function_exists('wpme_get_shortlink_handler') && get_option('fbseu_link_type') == 'shortlink'){add_filter( 'pre_get_shortlink', 'wpme_get_shortlink_handler', 1, 4 );} else {}
	$SECRET_EMAIL = get_option('fbseu_secret_email');
	$title = mb_encode_mimeheader($post->post_title);
	if(get_option('fbseu_link_type') == 'shortlink'){$href = wp_get_shortlink($post->ID);}else{$href = get_permalink($post->ID);}
	$from = get_option('admin_email');
	$headers = 'User-Agent: Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.7.12) Gecko/20050915'."\r\n"
				.'MIME-Version: 1.0'."\r\n"
				.'From: '.$from."\r\n"
				.'Content-Type: text/plain; charset=utf8; format=flowed'."\r\n"
				.'Content-Transfer-Encoding: 8bit'."\r\n";
	$subject = get_option('fbseu_subject_template');
	$placeholder = array("[title]","[url]");
	$pdata = array($title,$href);
	$subject = stripslashes_deep(str_ireplace($placeholder, $pdata, $subject));
	wp_mail( $SECRET_EMAIL, $subject , ' ',$headers );
	return $post->ID;
   
}

function fbseu_status_change($new_status, $old_status, $post) {
	if(get_option('fbseu_new_to_publish') == '1') {add_action('new_to_publish', 'fbseu_send_email');}
	if(get_option('fbseu_draft_to_publish') == '1' && ($old_status == 'draft' || $old_status == 'auto-draft')) {add_action('draft_to_publish', 'fbseu_send_email');}
	if(get_option('fbseu_pending_to_publish') == '1' && $old_status == 'pending') {add_action('pending_to_publish', 'fbseu_send_email');}
	if(get_option('fbseu_private_to_publish') == '1' && $old_status == 'private') {add_action('private_to_publish', 'fbseu_send_email');}
	if(get_option('fbseu_future_to_publish') == '1' && $old_status == 'future') {add_action('future_to_publish', 'fbseu_send_email');}
	
}
add_action('transition_post_status', 'fbseu_status_change', 10, 3);

?>